@@ -203,11 +203,11 @@ void PM_Interface::checkTemperatureStateChanges()
 		switch (_cur_state.TEMP_STATE) {
 		case CRITICAL:
 			_eM->executeEvent("temperature.critical");
-			pDebug(DBG_INFO, "Temperature state changed to critical.");
+			pDebug(DBG_WARN, "Temperature state changed to critical.");
 			break;
 		case HOT:
 			_eM->executeEvent("temperature.hot");
-			pDebug(DBG_INFO, "Temperature state changed to hot.");
+			pDebug(DBG_WARN, "Temperature state changed to hot.");
 			break;
 		case PASSIVE:
 			_eM->executeEvent("temperature.passive");
@@ -438,16 +438,15 @@ void PM_Interface::dethrottle()
 	}
 }
 
-void PM_Interface::resume()
+void PM_Interface::resume(CPUFREQ_MODE cpufreq_mode)
 {
 	pDebug(DBG_DIAG, "Daemon reinitialises system states, resume finished");
 	_requested_sleep_state = PSD_NO_SLEEP_REQUEST;
 	// reset frequency which may have changed without noticing it
 	cpufreq->reinitSpeeds();
 	/* reset CPU freq mode */
-	if (!cpufreq->setModes(config_obj->current_scheme->CPUFREQUENCY, _eM) < 0) {
-		pDebug(DBG_WARN, "Could not set CPUFreq mode");
-	}
+	if (cpufreq->isSupported())
+		cpufreq->setModes(cpufreq_mode, _eM);
 
 	checkACStateChanges();
 	checkBatteryStateChanges();
@@ -458,6 +457,7 @@ void PM_Interface::sleep_wrapper(const string &event)
 	static bool before_sleep = true;
 	static struct timeval cur_time;
 	static struct timezone dummy;
+	static CPUFREQ_MODE cpufreq_mode;
 
 	if (before_sleep) {
 		if (event == "suspend2disk") {
@@ -472,9 +472,10 @@ void PM_Interface::sleep_wrapper(const string &event)
 		}
 		ignore_buttons(true);
 
-		// we used to sync here, but we already sync in userspace and the
-		// kernel syncs again if necessary => this only slows things down
-//              sync();
+		if (cpufreq->isSupported()) {
+			cpufreq_mode = cpufreq->getMode();
+			cpufreq->setModes(_PERFORMANCE, _eM);
+		}
 
 		pDebug(DBG_INFO, "Set machine into sleep mode");
 
@@ -493,7 +494,8 @@ void PM_Interface::sleep_wrapper(const string &event)
 		_eM->adjustTimeouts(wakeuptime - sleeptime);
 		pDebug(DBG_INFO, "Back from %s inside sleep_wrapper", event.c_str());
 
-		resume();
+		resume(cpufreq_mode);
+
 		before_sleep = true;
 
 		// throw a resume event
