@@ -2,7 +2,7 @@
  *                                                                         *
  *                         Powersave Daemon                                *
  *                                                                         *
- *          Copyright (C) 2004,2005 SUSE Linux Products GmbH               *
+ *          Copyright (C) 2004,2005,2006 SUSE Linux Products GmbH          *
  *                                                                         *
  *             Author(s): Holger Macht <hmacht@suse.de>                    *
  *                                                                         *
@@ -93,8 +93,8 @@ void general_error()
 
 void no_connect_no_rights_error()
 {
-	fprintf(stderr, "Could not connect to powersaved because of missing permissions."
-		" Are you priviledged to connect to the powersaved?\n");
+	fprintf(stderr, "Could not connect to powersaved because of missing permissions.\n"
+		"Are you priviledged to connect to the powersaved?\n");
 }
 
 void no_connect_no_daemon_error()
@@ -478,6 +478,10 @@ int main(int argc, char **argv)
 			fprintf(stderr, "Suspend-To-RAM is not supported.\n");
 			ret = -1;
 			break;
+		case REPLY_NO_RIGHTS:
+			no_connect_no_rights_error();
+			ret = -2;
+			break;
 		case REPLY_DBUS_ERROR:
 			fprintf(stderr, "Cannot connect to powersaved. Is the daemon running? (%s)\n",
 				DBus_Error_Array[err_code]);
@@ -503,6 +507,10 @@ int main(int argc, char **argv)
 			fprintf(stderr, "Standby is not supported.\n");
 			ret = -1;
 			break;
+		case REPLY_NO_RIGHTS:
+			no_connect_no_rights_error();
+			ret = -2;
+			break;
 		case REPLY_DBUS_ERROR:
 			fprintf(stderr, "Cannot connect to powersaved. Is the daemon running? (%s)\n",
 				DBus_Error_Array[err_code]);
@@ -527,6 +535,10 @@ int main(int argc, char **argv)
 			fprintf(stderr, "Suspend-To-disk is not supported.\n");
 			ret = -1;
 			break;
+		case REPLY_NO_RIGHTS:
+			no_connect_no_rights_error();
+			ret = -2;
+			break;
 		case REPLY_DBUS_ERROR:
 			fprintf(stderr, "Cannot connect to powersaved. Is the daemon running? (%s)\n",
 				DBus_Error_Array[err_code]);
@@ -648,6 +660,10 @@ int main(int argc, char **argv)
 			cerr << "No Battery." << endl;
 			ret = -1;
 			break;
+		case REPLY_NO_RIGHTS:
+			no_connect_no_rights_error();
+			ret = -2;
+			break;
 		case REPLY_SUCCESS:
 			if (!dbusGetMessageString(reply, &dummy, 0) && dummy != NULL) {
 				result = dummy;
@@ -707,6 +723,10 @@ int main(int argc, char **argv)
 				printf("Scheme %s does not exist\n", schemeName);
 				ret = -1;
 				break;
+			case REPLY_NO_RIGHTS:
+				no_connect_no_rights_error();
+				ret = -2;
+				break;
 			default:
 				printf("Error: %s\n", DBus_Error_Array[err_code]);
 				general_error();
@@ -739,6 +759,9 @@ int main(int argc, char **argv)
 				fprintf(stderr, "Could not assign schemes to current/battery/ac_power\n");
 				ret = -1;
 			}
+		} else if (err_code == REPLY_NO_RIGHTS) {
+			no_connect_no_rights_error();
+			ret = -2;
 		} else {
 			general_error();
 			ret = -1;
@@ -1002,23 +1025,27 @@ int main(int argc, char **argv)
 			switch (err_code) {
 			case REPLY_DISABLED:
 				fprintf(stderr, "Device power management has been disabled by administrator.\n");
+				ret = -1;
+				break;
+			case REPLY_NO_RIGHTS:
+				no_connect_no_rights_error();
+				ret = -2;
 				break;
 			default:
 				general_error();
+				ret = -1;
+			}
+		} else {
+			char *device;
+			int state = -1;
+			int i = 0;
+			while (!dbusGetMessageString(reply, &device, i)
+			       && !dbusGetMessageInteger(reply, &state, i)) {
+				printf("Device [%d]: %s\n"
+				       "            power state: %d\n", i, device, state);
+				i++;
 			}
-			ret = -1;
 		}
-
-		char *device;
-		int state = -1;
-		int i = 0;
-		while (!dbusGetMessageString(reply, &device, i)
-		       && !dbusGetMessageInteger(reply, &state, i)) {
-			printf("Device [%d]: %s\n"
-			       "            power state: %d\n", i, device, state);
-			i++;
-		}
-	
 	}
 	if (DPM_GET_CLASSES) {
 		err_code = dbusSendMessageWithReply(REQUEST_MESSAGE, &reply, "DpmClassesGet",
@@ -1028,18 +1055,23 @@ int main(int argc, char **argv)
 			switch (err_code) {
 			case REPLY_DISABLED:
 				fprintf(stderr, "Device power management has been disabled by administrator.\n");
+				ret = -1;
+				break;
+			case REPLY_NO_RIGHTS:
+				no_connect_no_rights_error();
+				ret = -2;
 				break;
 			default:
 				general_error();
+				ret = -1;
+			}
+		} else {
+			char *c;
+			int i = 0;
+			while (!dbusGetMessageString(reply, &c, i)) {
+				printf("%s\n", c);
+				i++;
 			}
-			ret = -1;
-		}
-		
-		char *c;
-		int i = 0;
-		while (!dbusGetMessageString(reply, &c, i)) {
-			printf("%s\n", c);
-			i++;
 		}
 	}
 	if (DPM_SUSPEND) {
@@ -1111,23 +1143,32 @@ int main(int argc, char **argv)
 							  "ClientsGet");
 
 		if (err_code != REPLY_SUCCESS) {
-			general_error();
-			ret = -1;
-		}
-
-		char *name;
-		int cap;
-		int i = 0;
-		while (!dbusGetMessageString(reply, &name, i)) {
-			printf("Client name: %s", name);
-			if (!dbusGetMessageInteger(reply, &cap, i))
-				printf(", Capabilities: %d", cap);
-			printf("\n");
-			i++;
+			switch (err_code) {
+			case REPLY_NO_RIGHTS:
+				no_connect_no_rights_error();
+				ret = -2;
+				break;
+			default:
+				general_error();
+				ret = -1;
+			}
 		}
+		else {
+			char *name;
+			int cap;
+			int i = 0;
+			while (!dbusGetMessageString(reply, &name, i)) {
+				printf("Client name: %s", name);
+				if (!dbusGetMessageInteger(reply, &cap, i))
+					printf(", Capabilities: %d", cap);
+				printf("\n");
+				i++;
+			}
 		
-		if (!i)
-			printf("No clients connected\n");
+			if (!i)
+				printf("No clients connected\n");
+
+		}
 	}
 	if (VERSION_INFO) {
 #ifdef VERSION
